<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;
use Intuit\Jobs\AccountingCustomerUpdate;
use Intuit\Models\Customer;

use App\Models\{Account,ProviderOauth,Site,User};

class AccountingAccountAdd extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'accounting:account:add'
		.' {siteid : Site ID}'
		.' {provider : Provider Name}'
		.' {user : User Email}'
		.' {id : Account ID}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Add an account to the accounting provider';

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
		$site = Site::findOrFail($this->argument('siteid'));
		Config::set('site',$site);

		$so = ProviderOauth::where('name',$this->argument('provider'))->singleOrFail();
		$uo = User::where('email',$this->argument('user'))->singleOrFail();

		if (($x=$so->tokens->where('user_id',$uo->id))->count() !== 1)
			abort(500,sprintf('Unknown Tokens for [%s]',$uo->email));

		$ao = Account::findOrFail($this->argument('id'));

		$customer = new Customer;
		$customer->PrimaryEmailAddr = (object)['Address'=>$ao->user->email];
		$customer->ResaleNum = $ao->sid;
		$customer->GivenName = $ao->user->firstname;
		$customer->FamilyName = $ao->user->lastname;
		$customer->CompanyName = $ao->name;
		$customer->DisplayName = $ao->name;
		$customer->FullyQualifiedName = $ao->name;
		$customer->Active = (bool)$ao->active;

		return AccountingCustomerUpdate::dispatchSync($x->pop(),$customer);
    }
}
